#include "Gadget/Engine.h"

int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	Core G;
	G.Window.Open();
	G.Mouse.SetVisibility(true);
	G.Window.SetTitle("Animation - Sprite Sheets");

	glDisable(GL_DEPTH_TEST); //Ignore depth, we'll render everything from back to front

	//Open this image in PhotoShop, it is a sprite sheet. All 8 frames of animation are layed out in a 
	//grid pattern. We can display part of an image by changing the UV coordinates of the sprite. 
	//By Default, u1 = 0 and u2 = 1. Likewise, v1 = 0 and v2 = 1. So by default, the sprite displays
	//the entire image. By changing the UVs we can display the 8 frames of the explosion one at a time.
	Image explodeImg;
	explodeImg.Load("Images/Explode1.jpg");

	Sprite explodeSpr(400.0f, 400.0f);
	//Place the sprite in the center of the window
	explodeSpr.x = G.Window.GetWidth()/2.0f;
	explodeSpr.y = G.Window.GetHeight()/2.0f;

	float frame = 0.0f; //A variable to control the animation

	while(G.Window.IsOpen())//loop as long as the window is open
	{
		G.Renderer.BeginFrame(); G.Renderer.Render2D();

			//ESC closes the window
			if(G.Keyboard.GetKeyHold(GLFW_KEY_ESC)) {G.Window.Close();}	

			//Loop through the frames at a speed of 10 frames per second. Since there are only 8 frames
			//the animation should take less than a second
			frame += G.Timer.GetElapsedTime()*10.0f;
			//When we get to the end, start over.
			if(frame>=8.0f){frame = 0.0f;}

			//The sprite doesn't know anything about the image you are going to apply to it. So in order
			//for it to display the right frame, we need to tell it how frame there are and how they are
			//organized. The frames should always be in a grid pattern in your image, so we just need
			//to tell the sprite how many rows and how many columns there are. In this case there are 2 
			//rows and 4 columns.
			explodeSpr.SelectAnimationFrame(2, 4, int(frame));

			//Render the explosion
			Shader::Blend(3); //Additive blending
			explodeImg.Activate();
			explodeSpr.Render();

			Shader::Deactivate(); //Turns off any shaders or blending
			
		G.Renderer.EndFrame();	
	}
	return 0;
}			